| CorDdPlot | R Documentation |
This function plots the linear regression of genetic differentiation (Delta D) against geographic distance.
CorDdPlot(x, d, ncode)
x |
The genetic file, here is ge19900516qxh nepop format file. |
d |
Geographic distance.If D is TRUE, you should input the matrix of geographic distance; if no realistic distance,d should be set as NULL, then the default distance will be generated according to the order of the population sequence. |
ncode |
The type of your coding allele |
plot |
Return to a linear plot for the relation between genetic differentiation (Delta D) and geographic distance. |
lm |
Return to details of linear regression between genetic differentiation (Delta D) and geographic distance. |
qinxinghu@gmail.com
Qin, X., & Gaggiotti, O. E. (2022). Information-based summary statistics for spatial genetic structure inference. Molecular Ecology Resources, 22(6), 2183-2195.
Gaggiotti, O. E., Chao, A., Peres-Neto, P., Chiu, C. H., Edwards, C., Fortin, M. J., ... & Selkoe, K. A. (2018). Diversity from genes to ecosystems: A unifying framework to study variation across biological metrics and scales. Evolutionary Applications.
# example genepop file
#f <- system.file('extdata',package='HierDpart')
#infile <- file.path(f, "Island.gen")
#CorDdPlot(infile,d=NULL,ncode=3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.