print.boot.ppDeltaD: Print the bootstrapping result for pairwise allelic...

print_boot_ppDeltaDR Documentation

Print the bootstrapping result for pairwise allelic differentiation (Delta D)

Description

Print the confidence interval of pairwise allelic differentiation (Delta D)

Usage

print_boot_ppDeltaD(x, ...)

Arguments

x

boot.ppDeltaD object

...

Details

Print the bootstrapping result for pairwise allelic differentiation (Delta D)

Value

value

print the confidence interval of the pairwise allelic differentiation

Examples

f1 <- function(f) system.file("extdata", f,package="HierDpart")
boottest=boot.ppDeltaD(f1("Island.gen"),
ncode=3, nboot=999, quant = c(0.025, 0.975), diploid = TRUE)
print_boot_ppDeltaD(boottest)

xinghuq/HierDpart documentation built on March 21, 2023, 6:43 p.m.