pwDeltaD: Pairwise Shannon differentiation (Delta D)

View source: R/pwDeltaD.R

pwDeltaDR Documentation

Pairwise Shannon differentiation (Delta D)

Description

Estimating pairwise Shannon differentiation (Delta D)

Usage

pwDeltaD(x, para)

Arguments

x

Input file, data matrix or data frame

para

Indicating whether using parallel process

Details

Calculating pairwise Shannon differentiation, Delta D (Gaggiotti, O. E.,et al, 2018).

Value

PairwiseDeltaD

Pairwise Delta D

Note

Note that for windows system, the parallel doesn't work for multiple cores.In that case, users should set para=FALSE.

Author(s)

qinxinghu@gmail.com

References

Qin, X., & Gaggiotti, O. E. (2022). Information-based summary statistics for spatial genetic structure inference. Molecular Ecology Resources, 22(6), 2183-2195.

Gaggiotti, O. E., Chao, A., Peres-Neto, P., Chiu, C. H., Edwards, C., Fortin, M. J., ... & Selkoe, K. A. (2018). Diversity from genes to ecosystems: A unifying framework to study variation across biological metrics and scales. Evolutionary applications, 11(7), 1176-1193.

Examples

### Users can test the example in their own computer,
##as this is pairwise differentiation, using parallel
# will save more time
#f <- system.file('extdata',package='HierDpart')
#infile <- file.path(f, "Island.gen")
#library(adegenet)
#Islandfile=read.genepop(infile,ncode=3)
#Islandfreq=tab(Islandfile,freq=TRUE)
#IslandpwD=pwDeltaD(Islandfreq,para=FALSE)
#print(IslandpwD)


xinghuq/HierDpart documentation built on March 21, 2023, 6:43 p.m.