| print_boot_ppDeltaD | R Documentation |
Print the confidence interval of pairwise allelic differentiation (Delta D)
print_boot_ppDeltaD(x, ...)
x |
boot.ppDeltaD object |
... |
Print the bootstrapping result for pairwise allelic differentiation (Delta D)
value |
print the confidence interval of the pairwise allelic differentiation |
f1 <- function(f) system.file("extdata", f,package="HierDpart")
boottest=boot.ppDeltaD(f1("Island.gen"),
ncode=3, nboot=999, quant = c(0.025, 0.975), diploid = TRUE)
print_boot_ppDeltaD(boottest)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.